###################################
# Analysis 1 - heatmap preparation
###################################

rm(list=ls())
library(tidyverse)
library(sf)

# read data
osm500 <- st_read("data/OSM/osm2021_ibis_500m2.gpkg",layer = "osm500") # OpenStreetMap buildings > 500 m2
buildings2021NL <- st_read("data/Distributioncenters/distributioncenters2021NL.gpkg", layer = "buildings2021NL")  # distribution centres (DCs) in 2021

# function
heatmap <- function(yr,osm500,buildings2021NL){
      # Prepares point data for employment heatmaps per year, by defining the logistics sector, reading
      # and selecting data, intersecting data.
      # Since full Lisa microdata was only available until 2017, for the year 2020 the DC dataset is used.
      # Since not all DCs are present in Lisa data, manually observed DCs from DC dataset are added.
      #
      # Arguments: 
      #     x: year
      #     y: buildings dataset
      #     z: distribution centres dataset
      #
      # Returns geopackage of employment points and 
      # a csv file of aggregated employment numbers for further analysis.
      
      ## definition logistics in SBI sector codes
      logistics <- c("45111" , "45191" , "45311" , "45312" , "45401" , "46211" , "46212" , "46213" ,
               "46214" , "46215" , "46216" , "46217" , "46218" , "46219" , "4622" , "46231" , 
               "46232" , "46241" , "46242" , "46311" , "46312" , "4632" , "46331" , "46332" , 
               "4634" , "4635" , "4636" , "4637" , "46381" , "46382" , "46383" , "46384" , 
               "46389" , "4639" , "46411" , "46412" , "46421" , "46422" , "46423" , "46424" , 
               "46425" , "46429" , "46431" , "46432" , "46433" , "46434" , "46435" , "46436" , 
               "46441" , "46442" , "4645" , "46461" , "46462" , "46471" , "46472" , "46473" , 
               "4648" , "46491" , "46492" , "46493" , "46494" , "46495" , "46496" , "46497" , 
               "46498" , "46499" , "4651" , "4652" , "4661" , "4662" , "4663" , "4664" , "4665" ,
               "4666" , "46681" , "46682" , "46691" , "46692" , "46693" , "46694" , "46695" , 
               "46696" , "46697" , "46699" , "46711" , "46712" , "46713" , "46721" , "46722" , 
               "46723" , "46731" , "46732" , "46733" , "46734" , "46735" , "46736" , "46737" ,
               "46738" , "46739" , "46741" , "46742" , "46751" , "46752" , "46761" , "46762" , 
               "46769" , "46771" , "46772" , "46779" , "46901" , "46902","47911","47912","47913",
               "47914","47915","47916","47918","47919", "4920" , "4941",  "50201",  "50202" , 
               "50401" , "50402" , "50403" , "5121" , "52101" , "52102" , "52109" , "5221" , 
               "5222" , "5223" , "52241" , "52242" , "52291" , "52292", "5310", "53201", "53202")
      
      ## read Lisa data
      lisa <- read_csv(paste("data/Lisa_years/LISA",yr,".csv",sep="")) %>% filter(!is.na(XCOORD))
      lisa <- st_as_sf(lisa, coords = c("XCOORD","YCOORD"), crs = 28992)
      
      ## filter logistics firms in ibis business areas with jobs
      lisa %>% filter(SBI08 %in% logistics & ibis == 1 & BANEN >0) %>% select(COROPC,BANEN) %>%
            rename(Corop_nr = COROPC) %>% st_zm() -> lisas #drop z dim
      lisaOsmIntersect <- st_intersection(lisas, osm500)
      lisaOsmIntersect %>% select(Corop_nr,BANEN) -> lisaOsmInt
      ## filter and add manually checked and estimated warehouse jobs not present in lisa, from DC dataset
      buildings2021NL %>% filter(Constr_yea<= yr & Function_n != 3) %>% 
            select(osm_id,Corop_nr,BANEN) -> buildings
      x <- st_intersection(buildings,lisas)
      lisaBuildingsDifference <- subset(buildings, !(osm_id %in% x$osm_id))
                  #lisaBuildingsDifference <- st_difference(buildings, lisa) # function too slow, used ! instead
      lisaBuildingsDifference %>% select(Corop_nr,BANEN) -> buildDif
      centroids <- st_centroid(buildDif) %>% rename(geometry = geom)
      ## merge point data and save shapefile and csv
      banen <- rbind(lisaOsmInt,centroids)
      filename <- paste("processed/heatmapdata",yr,".gpkg",sep="")
            st_write(banen, dsn = filename, layer = "jobs", append = FALSE)
      ## csv per corop region
      banen %>% as_tibble() %>% select(-geometry) %>% group_by(Corop_nr) %>% 
            summarise(logjobs = sum(BANEN)) -> jobs
      filename2 <- paste("processed/jobs",yr,".csv",sep="")
            write_csv(jobs,filename2)
}

# execute heatmap data preparation function for:
heatmap(2000,osm500,buildings2021NL)
heatmap(2010,osm500,buildings2021NL)
heatmap(2017,osm500,buildings2021NL)

# prepare heatmap data for 2020 
## filter out jobs from non-current entries (based on lisa2017 version, see DC dataset documentation),
## but use all still existing buildings in 2020 in the graphics
buildings2021NL %>% filter(Constr_yea<= 2020 & Function_n != 3 & Current == 1) %>% 
      select(Corop_nr,Jobs_logis) %>% st_centroid() -> banen2020
st_write(banen2020, dsn = paste("processed/heatmapdata2020.gpkg",sep = ""), 
         layer = "jobs", append = FALSE)
# calculate aggregated employment numbers 2020 per corop region
banen2020 %>% as_tibble() %>% select(-geom) %>% group_by(Corop_nr) %>% 
      summarise(logjobs = sum(Jobs_logis)) -> jobs2020
write_csv(jobs2020,"processed/jobs2020.csv")