####################################################################
# Analysis - corop region comparison: m2, jobs, population per year
####################################################################

rm(list=ls())
library(tidyverse)
library(sf)


# Read data per corop (NUTS3) region
## note that in the Table of the paper, 2017 is used, whereas in the heatmap 2020 was used as most recent year,
## due to full microdata availability

## read population data
read.csv("data/CBS/CBS_corop_population_years.csv", sep = ";") -> cbs
cbs %>% as_tibble() %>% rename(year = ï..year) -> cbs
as.character(cbs$Corop_nr)->cbs$Corop_nr
cbs %>% filter(year == 2020) -> pop2020
cbs %>% filter(year == 2017) -> pop2017
cbs %>% filter(year == 2010) -> pop2010
cbs %>% filter(year == 2000) -> pop2000

## read DC building footprint data, group per corop, exlude xxl retail and co-activity categories
st_read("data/Distributioncenters/distributioncenters2021NL.gpkg",layer = "buildings2021NL") %>% as_tibble() -> NL
as.character(NL$Corop_nr)-> NL$Corop_nr
NL %>% filter(Constr_yea<= 2020 & Function_n < 3) %>% group_by(Corop_nr,Corop) %>%
      summarise(footprint = sum(Footprint)) -> foot2020
NL %>% filter(Constr_yea<= 2017 & Function_n < 3) %>% group_by(Corop_nr,Corop) %>%
      summarise(footprint = sum(Footprint)) -> foot2017
NL %>% filter(Constr_yea<= 2010 & Function_n < 3) %>% group_by(Corop_nr,Corop) %>%
      summarise(footprint = sum(Footprint)) -> foot2010
NL %>% filter(Constr_yea<= 2000 & Function_n < 3) %>% group_by(Corop_nr,Corop) %>%
      summarise(footprint = sum(Footprint)) -> foot2000

## prepare csv file for gis map of DC footprint growth per corop region (figure 1)
foot2000 %>% mutate(year = 2000) -> f2000
foot2017 %>% mutate(year = 2017) -> f2017
foot2020 %>% mutate(year = 2020) -> f2020
footgrowth <- rbind(f2000,f2017,f2020) 
pivot_wider(footgrowth, names_from = year, values_from = footprint) -> footgrowth_corop
footgrowth_corop %>% mutate(growth20 = `2020`/`2000`, growth17 = `2017`/`2000`) -> footgrowth_corop
write_csv(footgrowth_corop,"processed/footgrowth_corop.csv")

## read logistics jobs data in ibis areas with interpolation for missing jobs (results of Analysis_Heatmap_prep.R)
read_csv("processed/jobs2020.csv")-> jobs2020
      as.character(jobs2020$Corop_nr)->jobs2020$Corop_nr
read_csv("processed/jobs2017.csv")-> jobs2017
      as.character(jobs2017$Corop_nr)->jobs2017$Corop_nr
read_csv("processed/jobs2010.csv")-> jobs2010
      as.character(jobs2010$Corop_nr)->jobs2010$Corop_nr
read_csv("processed/jobs2000.csv")-> jobs2000
      as.character(jobs2000$Corop_nr)->jobs2000$Corop_nr

### read logistics, agrofood, tech and other jobs in entire corop regions 
coropjobs <- read_csv("processed/coropjobs_lisa2000_2010_2017.csv") # result of Analysis1_corop_data_selection.R
      coropjobs %>% rename(Corop_nr = COROPC) %>% select(-COROP) -> x
      as.character(x$Corop_nr)-> x$Corop_nr
pivot_wider(x, names_from = sector, values_from = jobs) -> y
jobtot2020 <- filter(y, year == 2020)
jobtot2017 <- filter(y, year == 2017)
jobtot2010 <- filter(y, year == 2010)
jobtot2000 <- filter(y, year == 2000)

# joining data per corop region per year
pop2020 %>%
      left_join(foot2020, by = "Corop_nr") %>% 
      left_join(jobtot2020, by = "Corop_nr") %>% 
      left_join(jobs2020, by = "Corop_nr") -> a
pop2017 %>%
      left_join(foot2017, by = "Corop_nr") %>% 
      left_join(jobtot2017, by = "Corop_nr") %>% 
      left_join(jobs2017, by = "Corop_nr") -> b
pop2010 %>%
      left_join(foot2010, by = "Corop_nr") %>% 
      left_join(jobtot2010, by = "Corop_nr") %>% 
      left_join(jobs2010, by = "Corop_nr") -> c
pop2000 %>%
      left_join(foot2000, by = "Corop_nr") %>% 
      left_join(jobtot2000, by = "Corop_nr") %>% 
      left_join(jobs2000, by = "Corop_nr") -> d
rbind(a,b,c,d) -> joindata


# calculate space quote (jobs per m2 of logistics), logistics jobs (regional / in DCS) per capita,
# and select regions for table (Table 1)
joindata %>% mutate(jobs_m = logjobs/footprint, jobs_cap = logjobs/population, 
                    logis_m = logistics/footprint, logis_cap = logistics/population) %>% 
      select(-c(Corop.x,Corop_nr, year.y)) %>% rename(Corop = Corop.y, year = year.x) %>%
filter(Corop %in% c('Arnhem/nijmegen', 'Groot-rijnmond', 'Midden-limburg','Midden-noord-brabant',
       'Noord-limburg', 'Noordoost-noord-brabant','West-noord-brabant','Zuidoost-noord-brabant', 
       'Zuidoost-zuid-holland', 'Zuidwest-gelderland')) -> coropdata


## Plot table 1
pivot_wider(coropdata, names_from = year, values_from = c(-Corop))-> coropwide
coropwide %>% mutate(population_growth = population_2017/population_2000 -1, 
      logis_growth = logistics_2017/ logistics_2000 -1, warehouse_growth = footprint_2017/footprint_2000 -1, 
      quote_growth = logis_m_2017/logis_m_2000 -1) %>%
select(Corop, population_growth, logistics_2000, logistics_2017, logis_growth, footprint_2000, 
       footprint_2017, warehouse_growth, logis_m_2000, logis_m_2017, quote_growth) -> table1
arrange(table1, desc(logis_growth)) -> table1
write_excel_csv2(table1, "plots/table1.xls")
